==> dl.php?src=linea21_1_7.zip: linea21/library/scripts/languages/ru.js <==
{
    "ALLOWED_FILE_TYPE": "Разрешены только указанные файлы: ", 
    "AUTHORIZATION_REQUIRED": "У вас не хватает прав для работы с менеджером файлов.", 
    "DIRECTORY_ALREADY_EXISTS": "Папка '%s' уже существует.", 
    "DIRECTORY_NOT_EXIST": "Папка %s не существует.", 
    "DISALLOWED_FILE_TYPE": "Указанные файлы запрещены: ", 
    "ERROR_RENAMING_DIRECTORY": "Ошибка при переименовании папки %s в %s.", 
    "ERROR_RENAMING_FILE": "Ошибка при переименовании файла %s в %s.", 
    "FILE_ALREADY_EXISTS": "Файл '%s' уже существует.", 
    "FILE_DOES_NOT_EXIST": "Файл %s не существует.", 
    "INVALID_ACTION": "Неверное действие.", 
    "INVALID_DIRECTORY_OR_FILE": "Неверная папка или файл.", 
    "INVALID_FILE_TYPE": "Загрузка файла запрещена.", 
    "INVALID_FILE_UPLOAD": "Загружен некорректный файл.", 
    "INVALID_VAR": "Неверная переменная %s.", 
    "LANGUAGE_FILE_NOT_FOUND": "Файл с настройками для языка не найден.", 
    "MODE_ERROR": "Ошибка режима.", 
    "UNABLE_TO_CREATE_DIRECTORY": "Не могу создать папку %s.", 
    "UNABLE_TO_OPEN_DIRECTORY": "Не могу открыть папку %s.", 
    "UPLOAD_FILES_SMALLER_THAN": "Пожалуйста, загружайте файлы не больше %s.", 
    "UPLOAD_IMAGES_ONLY": "Пожалуйста, загружайте только изображения, другие типы файлов не поддерживаются.", 
    "UPLOAD_IMAGES_TYPE_JPEG_GIF_PNG": "Пожалуйста, загружайте только изображения типа JPEG, GIF или PNG.", 
    "browse": "...", 
    "bytes": " байт", 
    "cancel": "Отмена", 
    "confirmation_delete": "Вы уверены, что хотите удалить этот файл?", 
    "could_not_retrieve_folder": "Не могу получить содержимое папки.", 
    "create_folder": "Создать папку", 
    "created": "Создан", 
    "current_folder": "Текущая папка: ", 
    "default_foldername": "Моя папка", 
    "del": "Удалить", 
    "dimensions": "Размеры", 
    "download": "Скачать", 
    "fck_select_integration": "Функция 'Выбрать' используется только для интеграции с FCKEditor.", 
    "file_size_limit": "Ограничение на размер файла: ", 
    "file_too_big": "Файл слишком большой.", 
    "gb": "Гб", 
    "grid_view": "Переключиться в режим сетки", 
    "kb": "Кб", 
    "list_view": "Переключиться в режим списка", 
    "loading_data": "Загрузка...", 
    "mb": "Мб", 
    "modified": "Изменён", 
    "move": "Move to ...", 
    "name": "Имя", 
    "new_filename": "Введите новое имя файла", 
    "new_folder": "New folder", 
    "no": "Нет", 
    "no_foldername": "Не введено имя папки.", 
    "parentfolder": "На уровень выше", 
    "prompt_foldername": "Введите имя новой папки", 
    "rename": "Переименовать", 
    "search": "Поиск", 
    "search_reset": "Сброс", 
    "select": "Выбрать", 
    "select_from_left": "Выберите элемент слева.", 
    "size": "Размер", 
    "successful_added_file": "Новый файл добавлен успешно.", 
    "successful_added_folder": "Новая папка добавлена успешно.", 
    "successful_delete": "Удаление прошло успешно.", 
    "successful_moved": "Move successful.", 
    "successful_rename": "Переименование успешно.", 
    "upload": "Загрузить", 
    "yes": "Да"
}

==> dl.php?src=linea21_1_8.zip: linea21/library/scripts/languages/ru.js <==
{
    "ALLOWED_FILE_TYPE": "Разрешены только указанные файлы: ", 
    "AUTHORIZATION_REQUIRED": "У вас не хватает прав для работы с менеджером файлов.", 
    "DIRECTORY_ALREADY_EXISTS": "Папка '%s' уже существует.", 
    "DIRECTORY_NOT_EXIST": "Папка %s не существует.", 
    "DISALLOWED_FILE_TYPE": "Указанные файлы запрещены: ", 
    "ERROR_CREATING_ZIP": "Error creating Zip archive", 
    "ERROR_OPENING_FILE": "Error opening file.", 
    "ERROR_RENAMING_DIRECTORY": "Ошибка при переименовании папки %s в %s.", 
    "ERROR_RENAMING_FILE": "Ошибка при переименовании файла %s в %s.", 
    "ERROR_REPLACING_FILE": "Please, provide a file having the following extension :", 
    "ERROR_SAVING_FILE": "Error saving file.", 
    "ERROR_UPLOADING_FILE": "Error uploading file.", 
    "ERROR_WRITING_PERM": "You don't have write permissions on that file.", 
    "FILE_ALREADY_EXISTS": "Файл '%s' уже существует.", 
    "FILE_DOES_NOT_EXIST": "Файл %s не существует.", 
    "INVALID_ACTION": "Неверное действие.", 
    "INVALID_DIRECTORY_OR_FILE": "Неверная папка или файл.", 
    "INVALID_FILE_TYPE": "Загрузка файла запрещена.", 
    "INVALID_FILE_UPLOAD": "Загружен некорректный файл.", 
    "INVALID_VAR": "Неверная переменная %s.", 
    "LANGUAGE_FILE_NOT_FOUND": "Файл с настройками для языка не найден.", 
    "MODE_ERROR": "Ошибка режима.", 
    "NOT_ALLOWED": "You are not allowed to process this action", 
    "NOT_ALLOWED_SYSTEM": "System permissions do not allow you to perform this action", 
    "UNABLE_TO_CREATE_DIRECTORY": "Не могу создать папку %s.", 
    "UNABLE_TO_OPEN_DIRECTORY": "Не могу открыть папку %s.", 
    "UPLOAD_FILES_SMALLER_THAN": "Пожалуйста, загружайте файлы не больше %s.", 
    "UPLOAD_IMAGES_ONLY": "Пожалуйста, загружайте только изображения, другие типы файлов не поддерживаются.", 
    "UPLOAD_IMAGES_TYPE_JPEG_GIF_PNG": "Пожалуйста, загружайте только изображения типа JPEG, GIF или PNG.", 
    "browse": "...", 
    "bytes": " байт", 
    "cancel": "Отмена", 
    "close": "Close", 
    "confirmation_delete": "Вы уверены, что хотите удалить этот файл?", 
    "copied": "URL copied !", 
    "copy_to_clipboard": "Copy to Clipboard", 
    "could_not_retrieve_folder": "Не могу получить содержимое папки.", 
    "create_folder": "Создать папку", 
    "created": "Создан", 
    "current_folder": "Текущая папка: ", 
    "default_foldername": "Моя папка", 
    "del": "Удалить", 
    "dimensions": "Размеры", 
    "download": "Скачать", 
    "dz_dictDefaultMessage": "Drop files here to upload", 
    "dz_dictFallbackMessage": "Your browser does not support drag'n'drop file uploads.", 
    "dz_dictInvalidFileType": "You can't upload files of this type.", 
    "dz_dictMaxFilesExceeded": "Only %s simultaneous uploads are allowed.", 
    "edit": "Edit file", 
    "fck_select_integration": "Функция 'Выбрать' используется только для интеграции с FCKEditor.", 
    "file_size_limit": "Ограничение на размер файла: ", 
    "file_too_big": "Файл слишком большой.", 
    "gb": "Гб", 
    "grid_view": "Переключиться в режим сетки", 
    "help_move": "The use of '../' is forbidden. You can access root folder by using '/'.", 
    "items": "items", 
    "kb": "Кб", 
    "list_view": "Переключиться в режим списка", 
    "loading_data": "Загрузка...", 
    "mb": "Мб", 
    "modified": "Изменён", 
    "move": "Move to ...", 
    "name": "Имя", 
    "new_filename": "Введите новое имя файла", 
    "new_folder": "New folder", 
    "no": "Нет", 
    "no_foldername": "Не введено имя папки.", 
    "parentfolder": "На уровень выше", 
    "prompt_foldername": "Введите имя новой папки", 
    "quit_editor": "Quit editor", 
    "rename": "Переименовать", 
    "replace": "Replace file", 
    "save": "Save", 
    "search": "Поиск", 
    "search_reset": "Сброс", 
    "select": "Выбрать", 
    "select_from_left": "Выберите элемент слева.", 
    "size": "Размер", 
    "successful_added_file": "Новый файл добавлен успешно.", 
    "successful_added_folder": "Новая папка добавлена успешно.", 
    "successful_delete": "Удаление прошло успешно.", 
    "successful_edit": "Content update successful.", 
    "successful_moved": "Move successful.", 
    "successful_rename": "Переименование успешно.", 
    "successful_replace": "File replacement successful.", 
    "support_fm": "Filemanager is a free software, please support !", 
    "upload": "Загрузить", 
    "version": "version", 
    "yes": "Да"
}
